@@ -216,3 +216,23 @@ class Users:
         if does_no_exists:
             return []
         return json_loaded_response
+    
+    def get_shared_games(self, steam_id: str, token: str, include_owned: bool = False) -> dict:
+        """Gets shared games from family library. This is an undocumented API endpoint.
+
+        Args:
+            steam_id (str): Steam 64 ID
+            token (str): Steam access token (can be fetched from https://store.steampowered.com/pointssummary/ajaxgetasyncconfig)
+        """
+        # The parameter include_own needs to be set to get all shared games. Apart from its name, it does not mean to get games the user owns.
+        response = self.__client.request(
+            "get", 
+            "/IFamilyGroupsService/GetSharedLibraryApps/v1",
+            params={"steamids": steam_id, "access_token": token, "family_groupid": 0, "include_own": 1, "include_non_games": 0, "include_excluded": 0, "include_free": 0},
+        )["response"]
+        if not include_owned:
+            response["apps"] = [game for game in response["apps"] if steam_id not in game["owner_steamids"]]
+        # Filter out family-excluded games like MMO/MP games and delisted games.
+        # These games are usually not excluded by the include_excluded or include_free parameters (but still unavailable to share)
+        response["apps"] = [game for game in response["apps"] if game["exclude_reason"] == 0]
+        return response
\ No newline at end of file
